Repository: incubator-airflow
Updated Branches:
  refs/heads/master b755d3547 -> dc78b9196


http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/mysql_operator.py
----------------------------------------------------------------------
diff --git a/airflow/operators/mysql_operator.py 
b/airflow/operators/mysql_operator.py
index e3f1cd7..f7c94bf 100644
--- a/airflow/operators/mysql_operator.py
+++ b/airflow/operators/mysql_operator.py
@@ -27,7 +27,7 @@ class MySqlOperator(BaseOperator):
 
     :param mysql_conn_id: reference to a specific mysql database
     :type mysql_conn_id: string
-    :param sql: the sql code to be executed
+    :param sql: the sql code to be executed. (templated)
     :type sql: Can receive a str representing a sql statement,
         a list of str (sql statements), or reference to a template file.
         Template reference are recognized by str ending in '.sql'

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/mysql_to_hive.py
----------------------------------------------------------------------
diff --git a/airflow/operators/oracle_operator.py 
b/airflow/operators/oracle_operator.py
index 1ab44a4..c08908b 100644
--- a/airflow/operators/oracle_operator.py
+++ b/airflow/operators/oracle_operator.py
@@ -26,7 +26,7 @@ class OracleOperator(BaseOperator):
     Executes sql code in a specific Oracle database
     :param oracle_conn_id: reference to a specific Oracle database
     :type oracle_conn_id: string
-    :param sql: the sql code to be executed
+    :param sql: the sql code to be executed. (templated)
     :type sql: Can receive a str representing a sql statement,
         a list of str (sql statements), or reference to a template file.
         Template reference are recognized by str ending in '.sql'

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/pig_operator.py
----------------------------------------------------------------------
diff --git a/airflow/operators/pig_operator.py 
b/airflow/operators/pig_operator.py
index 05cc565..f7babcf 100644
--- a/airflow/operators/pig_operator.py
+++ b/airflow/operators/pig_operator.py
@@ -27,7 +27,7 @@ class PigOperator(BaseOperator):
     """
     Executes pig script.
 
-    :param pig: the pig latin script to be executed
+    :param pig: the pig latin script to be executed. (templated)
     :type pig: string
     :param pig_cli_conn_id: reference to the Hive database
     :type pig_cli_conn_id: string

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/postgres_operator.py
----------------------------------------------------------------------
diff --git a/airflow/operators/postgres_operator.py 
b/airflow/operators/postgres_operator.py
index aff3e69..5935f83 100644
--- a/airflow/operators/postgres_operator.py
+++ b/airflow/operators/postgres_operator.py
@@ -27,7 +27,7 @@ class PostgresOperator(BaseOperator):
 
     :param postgres_conn_id: reference to a specific postgres database
     :type postgres_conn_id: string
-    :param sql: the sql code to be executed
+    :param sql: the sql code to be executed. (templated)
     :type sql: Can receive a str representing a sql statement,
         a list of str (sql statements), or reference to a template file.
         Template reference are recognized by str ending in '.sql'

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/presto_to_mysql.py
----------------------------------------------------------------------
diff --git a/airflow/operators/python_operator.py 
b/airflow/operators/python_operator.py
index 3a681a6..497bb76 100644
--- a/airflow/operators/python_operator.py
+++ b/airflow/operators/python_operator.py
@@ -55,7 +55,7 @@ class PythonOperator(BaseOperator):
     :param templates_dict: a dictionary where the values are templates that
         will get templated by the Airflow engine sometime between
         ``__init__`` and ``execute`` takes place and are made available
-        in your callable's context after the template has been applied
+        in your callable's context after the template has been applied. 
(templated)
     :type templates_dict: dict of str
     :param templates_exts: a list of file extensions to resolve while
         processing templated fields, for examples ``['.sql', '.hql']``

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/s3_file_transform_operator.py
----------------------------------------------------------------------
diff --git a/airflow/operators/s3_file_transform_operator.py 
b/airflow/operators/s3_file_transform_operator.py
index 67286b0..f86153d 100644
--- a/airflow/operators/s3_file_transform_operator.py
+++ b/airflow/operators/s3_file_transform_operator.py
@@ -43,11 +43,11 @@ class S3FileTransformOperator(BaseOperator):
     S3 Select is also available to filter the source contents. Users can
     omit the transformation script if S3 Select expression is specified.
 
-    :param source_s3_key: The key to be retrieved from S3
+    :param source_s3_key: The key to be retrieved from S3. (templated)
     :type source_s3_key: str
     :param source_aws_conn_id: source s3 connection
     :type source_aws_conn_id: str
-    :param dest_s3_key: The key to be written from S3
+    :param dest_s3_key: The key to be written from S3. (templated)
     :type dest_s3_key: str
     :param dest_aws_conn_id: destination s3 connection
     :type dest_aws_conn_id: str

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/s3_to_hive_operator.py
----------------------------------------------------------------------
diff --git a/airflow/operators/sqlite_operator.py 
b/airflow/operators/sqlite_operator.py
index 0ccb1b3..91497f5 100644
--- a/airflow/operators/sqlite_operator.py
+++ b/airflow/operators/sqlite_operator.py
@@ -27,7 +27,7 @@ class SqliteOperator(BaseOperator):
 
     :param sqlite_conn_id: reference to a specific sqlite database
     :type sqlite_conn_id: string
-    :param sql: the sql code to be executed
+    :param sql: the sql code to be executed. (templated)
     :type sql: string or string pointing to a template file. File must have
         a '.sql' extensions.
     """

Reply via email to
diff --git a/airflow/operators/mysql_to_hive.py 
b/airflow/operators/mysql_to_hive.py
index 2915b7e..22b7ac2 100644
--- a/airflow/operators/mysql_to_hive.py
+++ b/airflow/operators/mysql_to_hive.py
@@ -43,10 +43,10 @@ class MySqlToHiveTransfer(BaseOperator):
     stage the data into a temporary table before loading it into its
     final destination using a ``HiveOperator``.
 
     :param sql: SQL query to execute against the MySQL database
     :type sql: str
     :param hive_table: target Hive table, use dot notation to target a
-        specific database
+        specific database. (templated)
     :type hive_table: str
     :param create: whether to create the table if it doesn't exist
     :type create: bool
@@ -54,7 +54,7 @@ class MySqlToHiveTransfer(BaseOperator):
         execution
     :type recreate: bool
     :param partition: target partition as a dict of partition columns
-        and values
+        and values. (templated)
     :type partition: dict
     :param delimiter: field delimiter in the file
     :type delimiter: str

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/oracle_operator.py
----------------------------------------------------------------------
@@ -43,10 +43,10 @@ class MySqlToHiveTransfer(BaseOperator):
     final destination using a ``HiveOperator``.
 
-    :param sql: SQL query to execute against the MySQL database
+    :param sql: SQL query to execute against the MySQL database. (templated)
     :type sql: str
     :param hive_table: target Hive table, use dot notation to target a
diff --git a/airflow/operators/presto_to_mysql.py 
b/airflow/operators/presto_to_mysql.py
index a4abc1f..0e2e7f7 100644
--- a/airflow/operators/presto_to_mysql.py
+++ b/airflow/operators/presto_to_mysql.py
@@ -28,19 +28,19 @@ class PrestoToMySqlTransfer(BaseOperator):
     into memory before being pushed to MySQL, so this operator should
     be used for smallish amount of data.
 
     :param sql: SQL query to execute against Presto
     :type sql: str
     :param mysql_table: target MySQL table, use dot notation to target a
-        specific database
+        specific database. (templated)
     :type mysql_table: str
     :param mysql_conn_id: source mysql connection
     :type mysql_conn_id: str
     :param presto_conn_id: source presto connection
     :type presto_conn_id: str
     :param mysql_preoperator: sql statement to run against mysql prior to
-        import, typically use to truncate of delete in place of the data
-        coming in, allowing the task to be idempotent (running the task
-        twice won't double load data)
+        import, typically use to truncate of delete in place
+        of the data coming in, allowing the task to be idempotent (running
+        the task twice won't double load data). (templated)
     :type mysql_preoperator: str
     """
 

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/python_operator.py
----------------------------------------------------------------------
@@ -28,19 +28,19 @@ class PrestoToMySqlTransfer(BaseOperator):
     be used for smallish amount of data.
 
-    :param sql: SQL query to execute against Presto
+    :param sql: SQL query to execute against Presto. (templated)
     :type sql: str
     :param mysql_table: target MySQL table, use dot notation to target a
diff --git a/airflow/operators/s3_to_hive_operator.py 
b/airflow/operators/s3_to_hive_operator.py
index e9a979d..6105823 100644
--- a/airflow/operators/s3_to_hive_operator.py
+++ b/airflow/operators/s3_to_hive_operator.py
@@ -49,13 +49,13 @@ class S3ToHiveTransfer(BaseOperator):
     stage the data into a temporary table before loading it into its
     final destination using a ``HiveOperator``.
 
     :param s3_key: The key to be retrieved from S3
     :type s3_key: str
     :param field_dict: A dictionary of the fields name in the file
         as keys and their Hive types as values
     :type field_dict: dict
     :param hive_table: target Hive table, use dot notation to target a
-        specific database
+        specific database. (templated)
     :type hive_table: str
     :param create: whether to create the table if it doesn't exist
     :type create: bool
@@ -63,7 +63,7 @@ class S3ToHiveTransfer(BaseOperator):
         execution
     :type recreate: bool
     :param partition: target partition as a dict of partition columns
-        and values
+        and values. (templated)
     :type partition: dict
     :param headers: whether the file contains column names on the first
         line

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/slack_operator.py
----------------------------------------------------------------------
@@ -49,13 +49,13 @@ class S3ToHiveTransfer(BaseOperator):
     final destination using a ``HiveOperator``.
 
-    :param s3_key: The key to be retrieved from S3
+    :param s3_key: The key to be retrieved from S3. (templated)
     :type s3_key: str
     :param field_dict: A dictionary of the fields name in the file
diff --git a/airflow/operators/slack_operator.py 
b/airflow/operators/slack_operator.py
index b37558f..3fa8913 100644
--- a/airflow/operators/slack_operator.py
+++ b/airflow/operators/slack_operator.py
@@ -87,15 +87,17 @@ class SlackAPIPostOperator(SlackAPIOperator):
     """
     Posts messages to a slack channel
 
-    :param channel: channel in which to post message on slack name (#general) 
or ID (C12318391)
+    :param channel: channel in which to post message on slack name (#general) 
or
+        ID (C12318391). (templated)
     :type channel: string
-    :param username: Username that airflow will be posting to Slack as
+    :param username: Username that airflow will be posting to Slack as. 
(templated)
     :type username: string
     :param text: message to send to slack
     :type text: string
     :param icon_url: url to icon used for this message
     :type icon_url: string
-    :param attachments: extra formatting details - see 
https://api.slack.com/docs/attachments
+    :param attachments: extra formatting details. (templated)
+        - see https://api.slack.com/docs/attachments.
     :type attachments: array of hashes
     """
 

http://git-wip-us.apache.org/repos/asf/incubator-airflow/blob/dc78b919/airflow/operators/sqlite_operator.py
----------------------------------------------------------------------
@@ -87,15 +87,17 @@ class SlackAPIPostOperator(SlackAPIOperator):
(templated)
     :type username: string
-    :param text: message to send to slack
+    :param text: message to send to slack. (templated)
     :type text: string
     :param icon_url: url to icon used for this message